Visit the [AIEarth main page](https://engine-aiearth.aliyun.com/)
for more information.
    
    


# Quickstart
### SDK Installation
- Environment requirements
    * Python 3.x

    
- Build  & Install
    ```javascript
    # 加密打包
    ./build.sh so
    # 源码打包
    ./build.sh
    # 安装whl包
    ./install.sh
    ```

